@@ -4,7 +4,7 @@ from django.utils.translation import gettext_lazy as _
 
 class ArtdPriceListConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    verbose_name = _("ArtD Price List")
+    verbose_name = _("Price List")
     name = "artd_price_list"
 
     def ready(self):
